==> libsbml-3.3.2-src.zip: libsbml-3.3.2/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestCompartmentVolumeRule.java <==
/*
 *
 * @file    TestCompartmentVolumeRule.java
 * @brief   CompartmentVolumeRule unit tests
 *
 * @author  Akiya Jouraku (Java conversion)
 * @author  Ben Bornstein 
 *
 * $Id: TestCompartmentVolumeRule.java 8704 2009-01-04 02:26:05Z mhucka $
 * $HeadURL: https://sbml.svn.sourceforge.net/svnroot/sbml/trunk/libsbml/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestCompartmentVolumeRule.java $
 *
 * This test file was converted from src/sbml/test/TestCompartmentVolumeRule.c
 * with the help of conversion sciprt (ctest_converter.pl).
 *
 *<!---------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright 2005-2008 California Institute of Technology.
 * Copyright 2002-2005 California Institute of Technology and
 *                     Japan Science and Technology Corporation.
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 *--------------------------------------------------------------------------->*/


package org.sbml.libsbml.test.sbml;

import org.sbml.libsbml.*;

import java.io.File;
import java.lang.AssertionError;

public class TestCompartmentVolumeRule {

  static void assertTrue(boolean condition) throws AssertionError
  {
    if (condition == true)
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      return;
    }
    else if (a.equals(b))
    {
      return;
    }

    throw new AssertionError();
  }

  static void assertNotEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      throw new AssertionError();
    }
    else if (a.equals(b))
    {
      throw new AssertionError();
    }
  }

  static void assertEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(int a, int b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(int a, int b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }
  private Rule CVR;

  protected void setUp() throws Exception
  {
    CVR = new  AssignmentRule();
    CVR.setL1TypeCode(libsbml.SBML_COMPARTMENT_VOLUME_RULE);
    if (CVR == null);
    {
    }
  }

  protected void tearDown() throws Exception
  {
    CVR = null;
  }

  public void test_CompartmentVolumeRule_create()
  {
    assertTrue( CVR.getTypeCode() == libsbml.SBML_ASSIGNMENT_RULE );
    assertTrue( CVR.getL1TypeCode() == libsbml.SBML_COMPARTMENT_VOLUME_RULE );
    assertTrue( CVR.getNotes() == null );
    assertTrue( CVR.getAnnotation() == null );
    assertTrue( CVR.getFormula().equals("") == true );
    assertTrue( CVR.getType() == libsbml.RULE_TYPE_SCALAR );
    assertTrue( CVR.getVariable().equals("") == true );
    assertEquals( false, CVR.isSetVariable() );
  }

  public void test_CompartmentVolumeRule_createWith()
  {
    Rule cvr;
    cvr = new  RateRule("c", "v + 1");
    cvr.setL1TypeCode(libsbml.SBML_COMPARTMENT_VOLUME_RULE);
    assertTrue( cvr.getTypeCode() == libsbml.SBML_RATE_RULE );
    assertTrue( cvr.getL1TypeCode() == libsbml.SBML_COMPARTMENT_VOLUME_RULE );
    assertTrue( cvr.getNotes() == null );
    assertTrue( cvr.getAnnotation() == null );
    assertTrue(cvr.getFormula().equals( "v + 1"));
    assertTrue(cvr.getVariable().equals( "c"));
    assertTrue( cvr.getType() == libsbml.RULE_TYPE_RATE );
    assertEquals( true, cvr.isSetVariable() );
    cvr = null;
  }

  public void test_CompartmentVolumeRule_free_NULL()
  {
  }

  public void test_CompartmentVolumeRule_setCompartment()
  {
    String c;
    String compartment =  "cell";;
    CVR.setVariable(compartment);
    assertTrue(CVR.getVariable().equals(compartment));
    assertEquals( true, CVR.isSetVariable() );
    if (CVR.getVariable() == compartment);
    {
    }
    c = CVR.getVariable();
    CVR.setVariable(c);
    assertTrue(CVR.getVariable().equals(compartment));
    CVR.setVariable("");
    assertEquals( false, CVR.isSetVariable() );
    if (CVR.getVariable() != null);
    {
    }
  }

  /**
   * Loads the SWIG-generated libSBML Java module when this class is
   * loaded, or reports a sensible diagnostic message about why it failed.
   */
  static
  {
    String varname;
    String shlibname;

    if (System.getProperty("mrj.version") != null)
    {
      varname = "DYLD_LIBRARY_PATH";    // We're on a Mac.
      shlibname = "libsbmlj.jnilib and/or libsbml.dylib";
    }
    else
    {
      varname = "LD_LIBRARY_PATH";      // We're not on a Mac.
      shlibname = "libsbmlj.so and/or libsbml.so";
    }

    try
    {
      System.loadLibrary("sbmlj");
      // For extra safety, check that the jar file is in the classpath.
      Class.forName("org.sbml.libsbml.libsbml");
    }
    catch (SecurityException e)
    {
      e.printStackTrace();
      System.err.println("Could not load the libSBML library files due to a"+
                         " security exception.\n");
      System.exit(1);
    }
    catch (UnsatisfiedLinkError e)
    {
      e.printStackTrace();
      System.err.println("Error: could not link with the libSBML library files."+
                         " It is likely\nyour " + varname +
                         " environment variable does not include the directories\n"+
                         "containing the " + shlibname + " library files.\n");
      System.exit(1);
    }
    catch (ClassNotFoundException e)
    {
      e.printStackTrace();
      System.err.println("Error: unable to load the file libsbmlj.jar."+
                         " It is likely\nyour -classpath option and CLASSPATH" +
                         " environment variable\n"+
                         "do not include the path to libsbmlj.jar.\n");
      System.exit(1);
    }
  }
}

==> libsbml-4.0.0-src.zip: libsbml-4.0.0/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestCompartmentVolumeRule.java <==
/*
 *
 * @file    TestCompartmentVolumeRule.java
 * @brief   CompartmentVolumeRule unit tests
 *
 * @author  Akiya Jouraku (Java conversion)
 * @author  Ben Bornstein 
 *
 * $Id: TestCompartmentVolumeRule.java 10068 2009-08-21 18:54:20Z ajouraku $
 * $HeadURL: https://sbml.svn.sourceforge.net/svnroot/sbml/branches/libsbml-4/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestCompartmentVolumeRule.java $
 *
 * This test file was converted from src/sbml/test/TestCompartmentVolumeRule.c
 * with the help of conversion sciprt (ctest_converter.pl).
 *
 *<!---------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright 2005-2009 California Institute of Technology.
 * Copyright 2002-2005 California Institute of Technology and
 *                     Japan Science and Technology Corporation.
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 *--------------------------------------------------------------------------->*/


package org.sbml.libsbml.test.sbml;

import org.sbml.libsbml.*;

import java.io.File;
import java.lang.AssertionError;

public class TestCompartmentVolumeRule {

  static void assertTrue(boolean condition) throws AssertionError
  {
    if (condition == true)
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      return;
    }
    else if ( (a == null) || (b == null) )
    {
      throw new AssertionError();
    }
    else if (a.equals(b))
    {
      return;
    }

    throw new AssertionError();
  }

  static void assertNotEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      throw new AssertionError();
    }
    else if ( (a == null) || (b == null) )
    {
      return;
    }
    else if (a.equals(b))
    {
      throw new AssertionError();
    }
  }

  static void assertEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(int a, int b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(int a, int b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }
  private Rule CVR;

  protected void setUp() throws Exception
  {
    CVR = new  AssignmentRule(1,2);
    CVR.setL1TypeCode(libsbml.SBML_COMPARTMENT_VOLUME_RULE);
    if (CVR == null);
    {
    }
  }

  protected void tearDown() throws Exception
  {
    CVR = null;
  }

  public void test_CompartmentVolumeRule_create()
  {
    assertTrue( CVR.getTypeCode() == libsbml.SBML_ASSIGNMENT_RULE );
    assertTrue( CVR.getL1TypeCode() == libsbml.SBML_COMPARTMENT_VOLUME_RULE );
    assertTrue( CVR.getNotes() == null );
    assertTrue( CVR.getAnnotation() == null );
    assertTrue( CVR.getFormula().equals("") == true );
    assertTrue( CVR.getType() == libsbml.RULE_TYPE_SCALAR );
    assertTrue( CVR.getVariable().equals("") == true );
    assertEquals( false, CVR.isSetVariable() );
  }

  public void test_CompartmentVolumeRule_free_NULL()
  {
  }

  public void test_CompartmentVolumeRule_setCompartment()
  {
    String c;
    String compartment =  "cell";;
    CVR.setVariable(compartment);
    assertTrue(CVR.getVariable().equals(compartment));
    assertEquals( true, CVR.isSetVariable() );
    if (CVR.getVariable() == compartment);
    {
    }
    c = CVR.getVariable();
    CVR.setVariable(c);
    assertTrue(CVR.getVariable().equals(compartment));
    CVR.setVariable("");
    assertEquals( false, CVR.isSetVariable() );
    if (CVR.getVariable() != null);
    {
    }
  }

  /**
   * Loads the SWIG-generated libSBML Java module when this class is
   * loaded, or reports a sensible diagnostic message about why it failed.
   */
  static
  {
    String varname;
    String shlibname;

    if (System.getProperty("mrj.version") != null)
    {
      varname = "DYLD_LIBRARY_PATH";    // We're on a Mac.
      shlibname = "libsbmlj.jnilib and/or libsbml.dylib";
    }
    else
    {
      varname = "LD_LIBRARY_PATH";      // We're not on a Mac.
      shlibname = "libsbmlj.so and/or libsbml.so";
    }

    try
    {
      System.loadLibrary("sbmlj");
      // For extra safety, check that the jar file is in the classpath.
      Class.forName("org.sbml.libsbml.libsbml");
    }
    catch (SecurityException e)
    {
      e.printStackTrace();
      System.err.println("Could not load the libSBML library files due to a"+
                         " security exception.\n");
      System.exit(1);
    }
    catch (UnsatisfiedLinkError e)
    {
      e.printStackTrace();
      System.err.println("Error: could not link with the libSBML library files."+
                         " It is likely\nyour " + varname +
                         " environment variable does not include the directories\n"+
                         "containing the " + shlibname + " library files.\n");
      System.exit(1);
    }
    catch (ClassNotFoundException e)
    {
      e.printStackTrace();
      System.err.println("Error: unable to load the file libsbmlj.jar."+
                         " It is likely\nyour -classpath option and CLASSPATH" +
                         " environment variable\n"+
                         "do not include the path to libsbmlj.jar.\n");
      System.exit(1);
    }
  }
}
